
/* ArktisWM, 2019, GNU GPL3 */

#include <gtk/gtk.h>
#include <time.h>

static void cal_dx (gpointer calendar) {
    time_t secs;
    struct tm *tm;
    secs = time (NULL);
    tm = localtime (&secs);
    guint sday, smonth, syear, month, year;
    sday = tm->tm_mday;
    smonth = tm->tm_mon;
    syear  = 1900 + tm->tm_year;

    gtk_calendar_get_date (GTK_CALENDAR (calendar), &year, &month, NULL);
    if ( year == syear && month == smonth ) {
        gtk_calendar_select_day (GTK_CALENDAR (calendar), sday);
        gtk_calendar_mark_day (GTK_CALENDAR (calendar), sday);
    } else {
        gtk_calendar_clear_marks (GTK_CALENDAR (calendar));
        gtk_calendar_select_day (GTK_CALENDAR (calendar), 0);
    }
}

static void cal_dxc (GtkWidget *event_box, GdkEventButton *event, gpointer data) {
    if (event->type == GDK_BUTTON_PRESS && event->button == 3)  {
        char mb_click[16] = "calendar_set";
        execlp ("/bin/sh", "sh", "-c", mb_click, NULL);
    } else { 
        gtk_main_quit();
    }
}

static void cal_dclick () {
    char mb_dclick[16] = "defaultcalendar";
    execlp ("/bin/sh", "sh", "-c", mb_dclick, NULL);
}

int main( int argc, char *argv[] )
{
    static GtkWidget *window = NULL;
    GtkWidget *vbox, *event_box, *image, *label;

    gtk_init (&argc, &argv);
    gtk_rc_parse("/root/.arktiswm/cal-base/theme.rc");
    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    gtk_widget_set_name(window, "calendar_wid");
    g_signal_connect (G_OBJECT (window), "destroy",
                      G_CALLBACK (gtk_main_quit), NULL);
    gtk_window_set_resizable (GTK_WINDOW (window), FALSE);
    gtk_window_set_decorated (GTK_WINDOW (window), FALSE);
    gtk_window_set_skip_taskbar_hint (GTK_WINDOW (window), TRUE);
    gtk_window_set_skip_pager_hint (GTK_WINDOW (window), TRUE);
    gtk_window_set_position (GTK_WINDOW (window), GTK_WIN_POS_MOUSE);

    vbox = gtk_vbox_new (FALSE, 0);
    gtk_container_add (GTK_CONTAINER (window), vbox);

    event_box = gtk_event_box_new ();
    gtk_widget_set_name(event_box, "calendar_evn");
    gtk_container_add (GTK_CONTAINER (vbox), event_box);
    gtk_widget_show (event_box);
    gtk_widget_set_events (event_box, GDK_BUTTON_PRESS_MASK);
    g_signal_connect (event_box, "button-press-event",
                      G_CALLBACK (cal_dxc), G_OBJECT(event_box));
    gtk_widget_realize (event_box);
    gdk_window_set_cursor (event_box->window, gdk_cursor_new (GDK_HAND1));

    label = gtk_label_new ("");
    gtk_container_add (GTK_CONTAINER (vbox), label);

    image = gtk_image_new_from_file ("/root/.arktiswm/cal-base/default.png");
    gtk_container_add (GTK_CONTAINER (event_box), image);

    GtkWidget *calendar = gtk_calendar_new();
    gtk_widget_set_name(calendar, "calendar_cal");
    gtk_box_pack_start (GTK_BOX (vbox), calendar, FALSE, FALSE, 0);
    g_signal_connect (calendar, "day-selected-double-click", 
                      G_CALLBACK (cal_dclick), NULL);
    g_signal_connect (calendar, "month-changed",
                      G_CALLBACK (cal_dx), G_OBJECT(calendar));
    g_signal_connect (calendar, "next-year", G_CALLBACK (cal_dx),
                      G_OBJECT(calendar));
    g_signal_connect (calendar, "prev-year", G_CALLBACK (cal_dx),
                      G_OBJECT(calendar));
    g_signal_connect (calendar, "show", G_CALLBACK (cal_dx), G_OBJECT(calendar));

    GDate date;
    gchar str[128];
    guint year, month, day;
    gtk_calendar_get_date (GTK_CALENDAR (calendar), &year, &month, &day);
    g_date_set_dmy (&date, day, month + 1, year);
    g_date_strftime (str, 127, "%A, %x", &date);
    gtk_label_set_text (GTK_LABEL (label), (gchar *) &str);

    gtk_widget_show_all (window);
    gtk_main ();
    return 0;
}
